==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/rm.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    HHmm => "HH:mm",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-M",
    yMEd => "E, y-M-d",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMMdd => "dd.MM.y",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'week' w 'of' Y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "rm",
  date_format_full => "EEEE, 'ils' d 'da' MMMM y",
  date_format_long => "d 'da' MMMM y",
  date_format_medium => "dd-MM-y",
  date_format_short => "dd-MM-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "gli",
    "ma",
    "me",
    "gie",
    "ve",
    "so",
    "du",
  ],
  day_format_narrow => [
    "G",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "glindesdi",
    "mardi",
    "mesemna",
    "gievgia",
    "venderdi",
    "sonda",
    "dumengia",
  ],
  day_stand_alone_abbreviated => [
    "gli",
    "ma",
    "me",
    "gie",
    "ve",
    "so",
    "du",
  ],
  day_stand_alone_narrow => [
    "G",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "glindesdi",
    "mardi",
    "mesemna",
    "gievgia",
    "venderdi",
    "sonda",
    "dumengia",
  ],
  era_abbreviated => [
    "av. Cr.",
    "s. Cr.",
  ],
  era_narrow => [
    "av. Cr.",
    "s. Cr.",
  ],
  era_wide => [
    "avant Cristus",
    "suenter Cristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Romansh",
  month_format_abbreviated => [
    "schan.",
    "favr.",
    "mars",
    "avr.",
    "matg",
    "zercl.",
    "fan.",
    "avust",
    "sett.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "F",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "schaner",
    "favrer",
    "mars",
    "avrigl",
    "matg",
    "zercladur",
    "fanadur",
    "avust",
    "settember",
    "october",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "schan.",
    "favr.",
    "mars",
    "avr.",
    "matg",
    "zercl.",
    "fan.",
    "avust",
    "sett.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "F",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "schaner",
    "favrer",
    "mars",
    "avrigl",
    "matg",
    "zercladur",
    "fanadur",
    "avust",
    "settember",
    "october",
    "november",
    "december",
  ],
  name => "Romansh",
  native_language => "rumantsch",
  native_name => "rumantsch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/rm.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    HHmm => "HH:mm",
    HHmmss => "HH:mm:ss",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, d.M.",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    MMMMEd => "E d. MMMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    MMd => "d.MM.",
    MMdd => "dd.MM.",
    Md => "d.M.",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    mmss => "mm:ss",
    ms => "mm:ss",
    y => "y",
    yM => "y-M",
    yMEd => "E, y-M-d",
    yMM => "MM.y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMMdd => "dd.MM.y",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "rm",
  date_format_full => "EEEE, 'ils' d 'da' MMMM y",
  date_format_long => "d 'da' MMMM y",
  date_format_medium => "dd-MM-y",
  date_format_short => "dd-MM-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "gli",
    "ma",
    "me",
    "gie",
    "ve",
    "so",
    "du",
  ],
  day_format_narrow => [
    "G",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "glindesdi",
    "mardi",
    "mesemna",
    "gievgia",
    "venderdi",
    "sonda",
    "dumengia",
  ],
  day_stand_alone_abbreviated => [
    "gli",
    "ma",
    "me",
    "gie",
    "ve",
    "so",
    "du",
  ],
  day_stand_alone_narrow => [
    "G",
    "M",
    "M",
    "G",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "glindesdi",
    "mardi",
    "mesemna",
    "gievgia",
    "venderdi",
    "sonda",
    "dumengia",
  ],
  era_abbreviated => [
    "av. Cr.",
    "s. Cr.",
  ],
  era_narrow => [
    "av. Cr.",
    "s. Cr.",
  ],
  era_wide => [
    "avant Cristus",
    "suenter Cristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Romansh",
  month_format_abbreviated => [
    "schan.",
    "favr.",
    "mars",
    "avr.",
    "matg",
    "zercl.",
    "fan.",
    "avust",
    "sett.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "F",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "schaner",
    "favrer",
    "mars",
    "avrigl",
    "matg",
    "zercladur",
    "fanadur",
    "avust",
    "settember",
    "october",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "schan.",
    "favr.",
    "mars",
    "avr.",
    "matg",
    "zercl.",
    "fan.",
    "avust",
    "sett.",
    "oct.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "S",
    "F",
    "M",
    "A",
    "M",
    "Z",
    "F",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "schaner",
    "favrer",
    "mars",
    "avrigl",
    "matg",
    "zercladur",
    "fanadur",
    "avust",
    "settember",
    "october",
    "november",
    "december",
  ],
  name => "Romansh",
  native_language => "rumantsch",
  native_name => "rumantsch",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. quartal",
    "2. quartal",
    "3. quartal",
    "4. quartal",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
